@@ -1,18 +1,16 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/particle for details.
 
 import math
 import re
-import sys
 import unicodedata
+from html.entities import name2codepoint
 from typing import Optional
 
 
-def programmatic_name(name):
-    # type: (str) -> str
+def programmatic_name(name: str) -> str:
     "Return a name safe to use as a variable name."
     name = re.sub("0$", "_0", name)
     # Deal first with antiparticles of sparticles, e.g. "~d(R)~" antiparticle of "~d(R)"
@@ -36,8 +34,9 @@ def programmatic_name(name):
     return name.lstrip("_")
 
 
-def str_with_unc(value, upper, lower=None):
-    # type: (float, Optional[float], Optional[float]) -> str
+def str_with_unc(
+    value: float, upper: Optional[float], lower: Optional[float] = None
+) -> str:
     """
     Utility to print out an uncertainty with different or
     identical upper/lower bounds. Nicely formats numbers using PDG rule.
@@ -67,29 +66,22 @@ def str_with_unc(value, upper, lower=None):
     # This is normal notation
     if -3 < value_digits < 6:
         if error_digits < 0:
-            fsv = fse = ".{}f".format(-error_digits)
+            fsv = fse = f".{-error_digits}f"
         else:
             fsv = fse = ".0f"
 
     # This is scientific notation - a little odd, but better than the other options.
     else:
-        fsv = ".{}e".format(abs(error_digits - value_digits))
+        fsv = f".{abs(error_digits - value_digits)}e"
         pure_error_digits = int(math.floor(math.log10(error)))
 
         fse = ".0e" if error_digits == pure_error_digits else ".1e"
 
     # Now, print values based on upper=lower being true or not (even if they print the same)
     if upper != lower:
-        return "{value:{fsv}} + {upper:{fse}} - {lower:{fse}}".format(
-            value=value, upper=upper, lower=lower, fsv=fsv, fse=fse
-        )
+        return f"{value:{fsv}} + {upper:{fse}} - {lower:{fse}}"
 
-    # Only bother with unicode if this is Python 3.
-    pm = u"±" if sys.version_info >= (3,) else "+/-"
-
-    return "{value:{fsv}} {pm} {upper:{fse}}".format(
-        value=value, pm=pm, upper=upper, fsv=fsv, fse=fse
-    )
+    return f"{value:{fsv}} ± {upper:{fse}}"
 
 
 # List of greek letter names as used in Unicode (see unicodedata package)
@@ -103,7 +95,6 @@ _list_name_greek_letters = [
     "Gamma",
     "Iota",
     "Kappa",
-    "Lamda",  # Unicodedata library uses "lamda" for "lambda" :S!
     "Lambda",
     "Mu",
     "Nu",
@@ -123,8 +114,7 @@ _list_name_greek_letters = [
 _list_name_greek_letters += [item.lower() for item in _list_name_greek_letters]
 
 
-def greek_letter_name_to_unicode(letter):
-    # type: (str) -> str
+def greek_letter_name_to_unicode(letter: str) -> str:
     """
     Return a greek letter name as a Unicode character,
     the same as the input if no match is found.
@@ -135,19 +125,16 @@ def greek_letter_name_to_unicode(letter):
     Omega -> Ω
     omega -> ω
     """
+    case = "SMALL" if letter == letter.lower() else "CAPITAL"
+    name = letter.upper()
+
     try:
-        return unicodedata.lookup(
-            "GREEK {case} LETTER {name}".format(
-                case="SMALL" if letter == letter.lower() else "CAPITAL",
-                name=letter.upper(),
-            )
-        )
+        return unicodedata.lookup(f"GREEK {case} LETTER {name}")
     except KeyError:  # Unicodedata library uses "lamda" for "lambda", so that's an obvious miss
         return letter
 
 
-def latex_name_unicode(name):
-    # type: (str) -> str
+def latex_name_unicode(name: str) -> str:
     r"""
     Convert in particle names in LaTeX all greek letters by their unicode.
 
@@ -165,12 +152,11 @@ def latex_name_unicode(name):
     if "ambda" in name:
         name = name.replace("ambda", "amda")
     for gl in _list_name_greek_letters:
-        name = name.replace(r"\{}".format(gl), greek_letter_name_to_unicode(gl))
+        name = name.replace(fr"\{gl}", greek_letter_name_to_unicode(gl))
     return name
 
 
-def latex_to_html_name(name):
-    # type:(str) -> str
+def latex_to_html_name(name: str) -> str:
     """Conversion of particle names from LaTeX to HTML."""
     name = re.sub(r"\^\{(.*?)\}", r"<SUP>\1</SUP>", name)
     name = re.sub(r"\_\{(.*?)\}", r"<SUB>\1</SUB>", name)
@@ -178,7 +164,10 @@ def latex_to_html_name(name):
     name = re.sub(r"\\mathrm\{(.*?)\}", r"\1", name)
     name = re.sub(r"\\left\[(.*?)\\right\]", r"[\1] ", name)
     for gl in _list_name_greek_letters:
-        name = name.replace(r"\%s" % gl, "&%s;" % gl)
+        # Special formatting since for example
+        # f"{hex(html.entities.name2codepoint['Delta'])}" gives '0x394' whereas HTML needs 'x0394',
+        # as in '&#x0394;', equivalent to '&Delta;'
+        name = name.replace(fr"\{gl}", f"&#x{name2codepoint[gl]:04x};")
     name = re.sub(r"\\tilde\{(.*?)\}", r"\1&#771;", name)
     name = re.sub(r"\\overline\{(.*?)\}", r"\1&#773;", name)
     name = re.sub(r"\\bar\{(.*?)\}", r"\1&#773;", name)
