@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/particle for details.
@@ -11,7 +10,6 @@ for all particles in the loaded "database" CSV file, excluding nuclei.
 See the particle.literals and the pdgid.literals submodules for the actually exposed aliases.
 """
 
-from __future__ import absolute_import
 
 from .particle import Particle
 
